__version__='0.0.1'

from capslock.decorators import timing
from capslock.decorators import debug
from capslock.decorators import run_multiple_times
from capslock.decorators import require_root
from capslock.decorators import color_output